@@ -2,7 +2,6 @@ package com.seafile.seadroid2.ui.activities;
 
 import android.app.Activity;
 import android.content.Intent;
-import android.icu.text.CaseMap;
 import android.os.Bundle;
 import android.text.TextUtils;
 import android.view.LayoutInflater;
@@ -33,8 +32,8 @@ import com.seafile.seadroid2.databinding.LayoutFrameSwipeRvBinding;
 import com.seafile.seadroid2.enums.FileReturnActionEnum;
 import com.seafile.seadroid2.framework.datastore.DataManager;
 import com.seafile.seadroid2.framework.db.entities.RepoModel;
-import com.seafile.seadroid2.framework.db.entities.StarredModel;
 import com.seafile.seadroid2.framework.model.ResultModel;
+import com.seafile.seadroid2.framework.model.ServerInfo;
 import com.seafile.seadroid2.framework.model.activities.ActivityModel;
 import com.seafile.seadroid2.framework.util.Toasts;
 import com.seafile.seadroid2.framework.util.Utils;
@@ -48,6 +47,7 @@ import com.seafile.seadroid2.ui.main.MainActivity;
 import com.seafile.seadroid2.ui.markdown.MarkdownActivity;
 import com.seafile.seadroid2.ui.media.image.CarouselImagePreviewActivity;
 import com.seafile.seadroid2.ui.media.player.CustomExoVideoPlayerActivity;
+import com.seafile.seadroid2.ui.office_doc.OfficeDocumentWebActivity;
 import com.seafile.seadroid2.ui.sdoc.SDocWebViewActivity;
 import com.seafile.seadroid2.view.TipsViews;
 
@@ -396,16 +396,22 @@ public class AllActivitiesFragment extends BaseFragmentWithVM<ActivityViewModel>
 
     @OptIn(markerClass = UnstableApi.class)
     private void open(ActivityModel activityModel) {
+        Account account = SupportAccountManager.getInstance().getCurrentAccount();
+        if (account == null){
+            return;
+        }
+        ServerInfo serverInfo = SupportAccountManager.getInstance().getServerInfo(account);
+
         if (Utils.isViewableImage(activityModel.name)) {
 
             Intent getIntent = CarouselImagePreviewActivity.startThisFromActivities(requireContext(), activityModel);
             imagePreviewActivityLauncher.launch(getIntent);
 
-        } else if (activityModel.name.endsWith(Constants.Format.DOT_SDOC)) {
+        } else if (activityModel.name.endsWith(Constants.FileExtensions.DOT_SDOC)) {
             SDocWebViewActivity.openSdoc(getContext(), activityModel.repo_name, activityModel.repo_id, activityModel.path, activityModel.name);
 
-        } else if (activityModel.name.endsWith(Constants.Format.DOT_DRAW) || activityModel.name.endsWith(Constants.Format.DOT_EXDRAW)) {
-            SDocWebViewActivity.openDraw(getContext(), activityModel.repo_name, activityModel.repo_id, activityModel.path, activityModel.name);
+        } else if (Utils.isOnlyOfficeFile(activityModel.name) && serverInfo.isEnableOnlyOffice()) {
+            OfficeDocumentWebActivity.openDocument(getContext(), activityModel.repo_name, activityModel.repo_id, activityModel.path, activityModel.name);
 
         } else if (Utils.isVideoFile(activityModel.name)) {
             checkRemoteAndFileCache(activityModel, new Consumer<File>() {
