@@ -1,5 +1,6 @@
 package com.seafile.seadroid2.ui.media.image;
 
+import static android.view.View.GONE;
 import static android.view.View.VISIBLE;
 
 import android.content.res.Configuration;
@@ -10,7 +11,6 @@ import android.text.TextUtils;
 import android.view.LayoutInflater;
 import android.view.View;
 import android.view.ViewGroup;
-import android.webkit.MimeTypeMap;
 import android.widget.FrameLayout;
 import android.widget.ImageView;
 import android.widget.LinearLayout;
@@ -18,9 +18,11 @@ import android.widget.TextView;
 
 import androidx.annotation.NonNull;
 import androidx.annotation.Nullable;
+import androidx.annotation.OptIn;
 import androidx.exifinterface.media.ExifInterface;
 import androidx.lifecycle.Observer;
 import androidx.lifecycle.ViewModelProvider;
+import androidx.media3.common.util.UnstableApi;
 
 import com.blankj.utilcode.util.FileUtils;
 import com.blankj.utilcode.util.ScreenUtils;
@@ -48,6 +50,7 @@ import com.seafile.seadroid2.framework.glide.GlideApp;
 import com.seafile.seadroid2.framework.model.sdoc.FileProfileConfigModel;
 import com.seafile.seadroid2.framework.util.SLogs;
 import com.seafile.seadroid2.framework.util.ThumbnailUtils;
+import com.seafile.seadroid2.framework.util.Utils;
 import com.seafile.seadroid2.ui.base.fragment.BaseFragment;
 import com.seafile.seadroid2.view.DocProfileView;
 import com.seafile.seadroid2.view.photoview.OnPhotoTapListener;
@@ -61,6 +64,7 @@ import java.io.IOException;
 import java.util.HashMap;
 import java.util.Locale;
 
+@OptIn(markerClass = UnstableApi.class)
 public class PhotoFragment extends BaseFragment {
     public static final String TAG = "PhotoFragment";
     private FragmentPhotoViewBinding binding;
@@ -72,6 +76,7 @@ public class PhotoFragment extends BaseFragment {
 
     private OnPhotoTapListener onPhotoTapListener;
     private String serverUrl;
+    private File destinationFile;
 
     public void setOnPhotoTapListener(OnPhotoTapListener onPhotoTapListener) {
         this.onPhotoTapListener = onPhotoTapListener;
@@ -185,7 +190,7 @@ public class PhotoFragment extends BaseFragment {
         getViewModel().getSeafExceptionLiveData().observe(getViewLifecycleOwner(), new Observer<SeafException>() {
             @Override
             public void onChanged(SeafException e) {
-                binding.progressBar.setVisibility(View.GONE);
+                binding.progressBar.setVisibility(GONE);
                 binding.errorView.setVisibility(VISIBLE);
             }
         });
@@ -193,7 +198,7 @@ public class PhotoFragment extends BaseFragment {
         getViewModel().getFileDetailExceptionLiveData().observe(getViewLifecycleOwner(), new Observer<SeafException>() {
             @Override
             public void onChanged(SeafException e) {
-                binding.bottomProgressBar.setVisibility(View.GONE);
+                binding.bottomProgressBar.setVisibility(GONE);
                 binding.bottomErrorView.setVisibility(VISIBLE);
                 binding.bottomErrorDesc.setText(e.getMessage());
 
@@ -205,19 +210,19 @@ public class PhotoFragment extends BaseFragment {
             public void onChanged(DirentModel direntModel) {
                 if (direntModel == null) {
                     binding.photoView.setImageResource(R.drawable.icon_image_error_filled);
-                    binding.progressBar.setVisibility(View.GONE);
+                    binding.progressBar.setVisibility(GONE);
                     return;
                 }
 
                 if (TextUtils.isEmpty(direntModel.local_file_id)) {
                     getViewModel().download(direntModel);
                 } else {
-                    File file = getLocalDestinationFile(direntModel.repo_id, direntModel.repo_name, direntModel.full_path);
-                    if (FileUtils.isFileExists(file)) {
-                        if (isGif(fullPath)) {
-                            loadOriGifUrl(file.getAbsolutePath());
+                    destinationFile = getLocalDestinationFile(direntModel.repo_id, direntModel.repo_name, direntModel.full_path);
+                    if (FileUtils.isFileExists(destinationFile)) {
+                        if (Utils.isGif(fullPath)) {
+                            loadLocalGifFile(destinationFile.getAbsolutePath());
                         } else {
-                            loadOriUrl(file.getAbsolutePath());
+                            loadLocalImageFile(destinationFile.getAbsolutePath());
                         }
                     } else {
                         getViewModel().download(direntModel);
@@ -226,20 +231,15 @@ public class PhotoFragment extends BaseFragment {
             }
         });
 
-        getViewModel().getOriginalUrlLiveData().observe(getViewLifecycleOwner(), new Observer<String>() {
-            @Override
-            public void onChanged(String oriUrl) {
-                loadOriUrl(oriUrl);
-            }
-        });
 
         getViewModel().getDownloadedPathLiveData().observe(getViewLifecycleOwner(), new Observer<String>() {
             @Override
             public void onChanged(String rawPath) {
-                if (isGif(fullPath)) {
-                    loadOriGifUrl(rawPath);
+                destinationFile = new File(rawPath);
+                if (Utils.isGif(fullPath)) {
+                    loadLocalGifFile(destinationFile.getAbsolutePath());
                 } else {
-                    loadOriUrl(rawPath);
+                    loadLocalImageFile(destinationFile.getAbsolutePath());
                 }
             }
         });
@@ -247,7 +247,7 @@ public class PhotoFragment extends BaseFragment {
         getViewModel().getFileDetailLiveData().observe(getViewLifecycleOwner(), new Observer<FileProfileConfigModel>() {
             @Override
             public void onChanged(FileProfileConfigModel configModel) {
-                binding.bottomProgressBar.setVisibility(View.GONE);
+                binding.bottomProgressBar.setVisibility(GONE);
 
                 DocProfileView detailView = new DocProfileView(requireContext());
                 detailView.parseData(configModel);
@@ -483,12 +483,12 @@ public class PhotoFragment extends BaseFragment {
 
 
     private void load() {
-        if (binding.progressBar.getVisibility() == View.GONE) {
+        if (binding.progressBar.getVisibility() == GONE) {
             binding.progressBar.setVisibility(VISIBLE);
         }
 
         if (binding.errorView.getVisibility() == VISIBLE) {
-            binding.errorView.setVisibility(View.GONE);
+            binding.errorView.setVisibility(GONE);
         }
 
         if (!TextUtils.isEmpty(imageUrl)) {
@@ -500,6 +500,7 @@ public class PhotoFragment extends BaseFragment {
         getViewModel().getFileDetail(repoId, fullPath);
     }
 
+    //remote url
     private void loadUrl(String url) {
         GlideApp.with(this)
                 .load(url)
@@ -508,14 +509,14 @@ public class PhotoFragment extends BaseFragment {
                 .listener(new RequestListener<Drawable>() {
                     @Override
                     public boolean onLoadFailed(@Nullable GlideException e, @Nullable Object model, @NonNull Target<Drawable> target, boolean isFirstResource) {
-                        binding.progressBar.setVisibility(View.GONE);
+                        binding.progressBar.setVisibility(GONE);
                         binding.errorView.setVisibility(VISIBLE);
                         return false;
                     }
 
                     @Override
                     public boolean onResourceReady(@NonNull Drawable resource, @NonNull Object model, Target<Drawable> target, @NonNull DataSource dataSource, boolean isFirstResource) {
-                        binding.progressBar.setVisibility(View.GONE);
+                        binding.progressBar.setVisibility(GONE);
                         return false;
                     }
                 })
@@ -526,7 +527,8 @@ public class PhotoFragment extends BaseFragment {
         getViewModel().checkLocal(repoId, fullPath);
     }
 
-    private void loadOriUrl(String oriUrl) {
+    // local image file
+    private void loadLocalImageFile(String oriUrl) {
 //        String thumbnailUrl = convertThumbnailUrl(fullPath);
 //        String thumbKey = EncryptUtils.encryptMD5ToString(thumbnailUrl);
 //        // load thumbnail first
@@ -556,15 +558,19 @@ public class PhotoFragment extends BaseFragment {
                 .listener(new RequestListener<Drawable>() {
                     @Override
                     public boolean onLoadFailed(@Nullable GlideException e, @Nullable Object model, @NonNull Target<Drawable> target, boolean isFirstResource) {
-                        binding.progressBar.setVisibility(View.GONE);
+                        binding.progressBar.setVisibility(GONE);
                         binding.errorView.setVisibility(VISIBLE);
                         return false;
                     }
 
                     @Override
                     public boolean onResourceReady(@NonNull Drawable resource, @NonNull Object model, Target<Drawable> target, @NonNull DataSource dataSource, boolean isFirstResource) {
-                        binding.progressBar.setVisibility(View.GONE);
+                        binding.progressBar.setVisibility(GONE);
                         try {
+                            //
+//                            checkMotionPhoto(oriUrl);
+
+                            //
                             HashMap<String, String> hashMap = loadExifMeta(oriUrl);
                             addTextView(hashMap);
                         } catch (Exception e) {
@@ -575,8 +581,93 @@ public class PhotoFragment extends BaseFragment {
                 })
                 .into(binding.photoView);
     }
+//
+//    private void checkMotionPhoto(String localPath) {
+//        if (motionPhotoType == -1) {
+//            motionPhotoType = HeicNative.nativeCheckMotionPhotoType(localPath);
+//        }
+//
+//        if (motionPhotoType == HeicNative.MOTION_PHOTO_TYPE_HEIC) {
+//            binding.btnLivePhoto.setVisibility(VISIBLE);
+//        } else if (motionPhotoType == HeicNative.MOTION_PHOTO_TYPE_JPEG) {
+//            binding.btnLivePhoto.setVisibility(VISIBLE);
+//        } else {
+//            binding.btnLivePhoto.setVisibility(GONE);
+//        }
+//    }
 
-    private void loadOriGifUrl(String rawUrl) {
+    // no load yet.
+//    private int motionPhotoType = -1;
+//
+//    @Todo
+//    @OptIn(markerClass = Unstable.class)
+//    private void playLivePhotoVideo() {
+//
+//        try {
+//            MediaSource source = buildMotionPhotoMediaSource(destinationFile);
+//            if (source == null) {
+//                return;
+//            }
+//
+//            ExoPlayer exoPlayer = new ExoPlayer.Builder(requireContext()).build();
+//
+//            binding.playerView.setPlayer(exoPlayer);
+//            exoPlayer.addListener(new Player.Listener() {
+//                @Override
+//                public void onPlaybackStateChanged(int playbackState) {
+//                    switch (playbackState) {
+//                        case Player.STATE_BUFFERING: //loading
+//
+//                            break;
+//                        case Player.STATE_READY:
+//                            binding.photoView.setVisibility(View.INVISIBLE);
+//                            binding.playerView.setVisibility(View.VISIBLE);
+//                            break;
+//                        case Player.STATE_ENDED:
+//                            binding.photoView.setVisibility(View.VISIBLE);
+//                            binding.playerView.setVisibility(View.INVISIBLE);
+//                            break;
+//                    }
+//                }
+//            });
+//            exoPlayer.setMediaSource(source);
+//            exoPlayer.prepare();
+//            exoPlayer.play();
+//        } catch (IOException | XMPException e) {
+//            throw new RuntimeException(e);
+//        }
+//    }
+//
+//    @Todo
+//    private MediaSource buildMotionPhotoMediaSource(File imageFile) throws IOException, XMPException {
+//        if (motionPhotoType == -1) {
+//            motionPhotoType = HeicNative.nativeCheckMotionPhotoType(imageFile.getAbsolutePath());
+//        }
+//
+//        byte[] videoBytes = null;
+//        if (motionPhotoType == HeicNative.MOTION_PHOTO_TYPE_HEIC) {
+//            videoBytes = HeicNative.nativeExtractHeicMotionPhotoVideo(imageFile.getAbsolutePath());
+//        } else if (motionPhotoType == HeicNative.MOTION_PHOTO_TYPE_JPEG) {
+//            videoBytes = HeicNative.nativeExtractJpegMotionPhotoVideo(imageFile.getAbsolutePath());
+//        }
+//
+//        if (videoBytes == null || videoBytes.length == 0) {
+//            return null;
+//        }
+//
+//        androidx.media3.datasource.DataSource.Factory factory = new MotionPhotoDataSourceFactory(videoBytes);
+//
+//        MediaItem mediaItem = new MediaItem.Builder()
+//                .setUri(Uri.fromFile(imageFile))
+//                .build();
+//
+//        return new ProgressiveMediaSource.Factory(factory)
+//                .createMediaSource(mediaItem);
+//    }
+
+
+    // local gif file
+    private void loadLocalGifFile(String rawUrl) {
         GlideApp.with(this)
                 .asGif()
                 .load(rawUrl)
@@ -585,14 +676,14 @@ public class PhotoFragment extends BaseFragment {
                 .listener(new RequestListener<GifDrawable>() {
                     @Override
                     public boolean onLoadFailed(@Nullable GlideException e, @Nullable Object model, @NonNull Target<GifDrawable> target, boolean isFirstResource) {
-                        binding.progressBar.setVisibility(View.GONE);
+                        binding.progressBar.setVisibility(GONE);
                         binding.errorView.setVisibility(VISIBLE);
                         return false;
                     }
 
                     @Override
                     public boolean onResourceReady(@NonNull GifDrawable resource, @NonNull Object model, Target<GifDrawable> target, @NonNull DataSource dataSource, boolean isFirstResource) {
-                        binding.progressBar.setVisibility(View.GONE);
+                        binding.progressBar.setVisibility(GONE);
                         // 图片加载成功
                         SLogs.d(TAG, "loadOriGifUrl()", dataSource.name() + ": " + isFirstResource + ": " + rawUrl);
                         return false;
@@ -601,16 +692,6 @@ public class PhotoFragment extends BaseFragment {
                 .into(binding.photoView);
     }
 
-    private boolean isGif(String fileName) {
-        if (TextUtils.isEmpty(fileName)) {
-            return false;
-        }
-
-        String f = MimeTypeMap.getFileExtensionFromUrl(fileName);
-        String mime = MimeTypeMap.getSingleton().getMimeTypeFromExtension(f);
-        return mime != null && mime.equalsIgnoreCase("image/gif");
-    }
-
     private String convertThumbnailUrl(String fullPath) {
         if (TextUtils.isEmpty(serverUrl)) {
             return null;
